@@ -301,7 +301,7 @@ BaseColorMapPlotCompositeWidget::addColorMap(
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = ColorSelector::getColor(true);
+    local_color = libmassgui::ColorSelector::getColor(true);
 
   // Contrary to what we do with graphs, we cannot stuff more than one color map
   // into a color map plot, so just add a new plot.
