@@ -160,6 +160,17 @@ BaseTracePlotCompositeWidget::createMainMenu()
 
   mp_mainMenu->addAction(save_peak_list_to_clipboard_p);
 
+  QAction *save_peak_list_to_file_p =
+    new QAction("Save peak list to file", this);
+  save_peak_list_to_file_p->setStatusTip(tr("Save peak list to file"));
+  save_peak_list_to_file_p->setShortcut(QKeySequence("Ctrl+P, C"));
+
+  connect(save_peak_list_to_file_p, &QAction::triggered, [this]() {
+    savePeakListToFile();
+  });
+
+  mp_mainMenu->addAction(save_peak_list_to_file_p);
+
   mp_mainMenu->addSeparator();
 
   QMenu *integrations_menu_p = mp_mainMenu->addMenu("&Integrations");
@@ -193,8 +204,8 @@ BaseTracePlotCompositeWidget::createMainMenu()
 
   QMenu *noise_handling_menu_p = filters_menu_p->addMenu("Noise handling");
 
-  QAction *store_noise_sample_trace_action_p =
-    new QAction("Store trace as noise sample trace", dynamic_cast<QObject *>(this));
+  QAction *store_noise_sample_trace_action_p = new QAction(
+    "Store trace as noise sample trace", dynamic_cast<QObject *>(this));
   store_noise_sample_trace_action_p->setStatusTip(
     "Set the (selected) trace as a noise sample trace");
   connect(store_noise_sample_trace_action_p,
@@ -268,7 +279,7 @@ BaseTracePlotCompositeWidget::createMainMenu()
     if(!ok)
       qFatal("Failed to convert QVariant to double");
 
-    //qDebug() << "triggered with threshold value:" << threshold;
+    // qDebug() << "triggered with threshold value:" << threshold;
 
     // Get the source plottable that might be of interest to the user.
     QCPAbstractPlottable *source_plottable_p =
@@ -343,7 +354,7 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = ColorSelector::getColor(true);
+    local_color = libmassgui::ColorSelector::getColor(true);
 
   // We have to verify if there is a destination policy for this composite plot
   // widget. There are different situations.
@@ -747,7 +758,7 @@ void
 BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
 {
-   //qDebug() << "ENTER with base plot context:" << context.toString();
+  // qDebug() << "ENTER with base plot context:" << context.toString();
 
   // Call the base class that will fill-in various generic data, like the
   // file/sample name, the x and y ranges...
@@ -1083,6 +1094,44 @@ BaseTracePlotCompositeWidget::savePeakListToClipboard()
 }
 
 
+bool
+BaseTracePlotCompositeWidget::savePeakListToFile()
+{
+  // qDebug();
+
+  QString file_name = QFileDialog::getSaveFileName(
+    this, tr("Export to text file"), QDir::homePath(), tr("Any file type(*)"));
+
+  if(file_name.isEmpty())
+    return false;
+
+  // Check first how many plottables there are in the widget.
+
+  QCPGraph *source_graph_p =
+    static_cast<QCPGraph *>(plottableToBeUsedAsIntegrationSource());
+
+  if(source_graph_p == nullptr)
+    {
+      // We should inform the user if there are more than one plottable.
+
+      int plottable_count = mp_plotWidget->plottableCount();
+
+      if(plottable_count > 1)
+        QMessageBox::information(this,
+                                 "Save peak list to clipboard",
+                                 "Please select a single trace and try again.");
+
+      return false;
+    }
+
+  pappso::Trace trace =
+    static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
+      ->toTrace(source_graph_p);
+
+  return pappso::Utils::writeToFile(trace.toString(), file_name);
+}
+
+
 } // namespace minexpert
 
 } // namespace msxps
