@@ -245,7 +245,7 @@ BaseTracePlotWnd::finalNewTracePlotConfiguration(
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = ColorSelector::getRandomColor();
+    local_color = libmassgui::ColorSelector::getRandomColor();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
