@@ -757,7 +757,9 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
       if(m_indicesPair.first == std::numeric_limits<std::size_t>::max() ||
          m_indicesPair.second == std::numeric_limits<std::size_t>::min())
         {
-          // qDebug();
+          // qDebug() << "The indices values:" << m_indicesPair.first << "-"
+          //          << m_indicesPair.second;
+
           return false;
         }
     }
@@ -772,7 +774,9 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
       if(m_rtValuesPair.first == std::numeric_limits<double>::max() ||
          m_rtValuesPair.second == std::numeric_limits<double>::min())
         {
-          // qDebug();
+          // qDebug() << "The retention time values:" << m_rtValuesPair.first
+          //          << "-" << m_rtValuesPair.second;
+
           return false;
         }
     }
@@ -787,7 +791,9 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
       if(m_dtValuesPair.first == std::numeric_limits<double>::max() ||
          m_dtValuesPair.second == std::numeric_limits<double>::min())
         {
-          qDebug();
+          // qDebug() << "The drift time values:" << m_dtValuesPair.first << "-"
+          //          << m_dtValuesPair.second;
+
           return false;
         }
     }
@@ -803,7 +809,10 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
            std::numeric_limits<std::size_t>::max() ||
          m_precursorIndexPair.second == std::numeric_limits<std::size_t>::min())
         {
-          // qDebug();
+          // qDebug() << "The precursor index values :"
+          //          << m_precursorIndexPair.first << "-"
+          //          << m_precursorIndexPair.second;
+
           return false;
         }
     }
@@ -818,7 +827,10 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
       if(m_precursorMzValuesPair.first == std::numeric_limits<double>::max() ||
          m_precursorMzValuesPair.second == std::numeric_limits<double>::min())
         {
-          // qDebug();
+          // qDebug() << "The precursor m/z values:"
+          //          << m_precursorMzValuesPair.first << "-"
+          //          << m_precursorMzValuesPair.second;
+
           return false;
         }
     }
@@ -842,7 +854,10 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
          m_precursorChargePair.second ==
            std::numeric_limits<std::size_t>::max())
         {
-          // qDebug();
+          // qDebug() << "The precursor charge values:"
+          //          << m_precursorChargePair.first << "-"
+          //          << m_precursorChargePair.second;
+
           return false;
         }
     }
