@@ -225,6 +225,25 @@ MsRunDataSetTableViewWnd::initialize()
 
   mp_msRunDataSetTableViewProxyModel->setPrecision(mp_precision);
 
+  // Set explanatory text for the different filtering line edit widgets.
+
+  m_ui.indexLineEdit->setToolTip(
+    "The accepted syntax: \nval\nval1--val2\n< val\n> val\n< val1 > val2\n");
+
+  m_ui.retentionTimeLineEdit->setToolTip(
+    "The accepted syntax: \nval\nval%tol (tol is the tolerance)\nval1--val2\n< "
+    "val\n> val\n< val1 > val2\n");
+
+  m_ui.driftTimeLineEdit->setToolTip(
+    "The accepted syntax: \nval\nval%tol (tol is the tolerance)\nval1--val2\n< "
+    "val\n> val\n< val1 > val2\n");
+
+  m_ui.precursorIndexLineEdit->setToolTip(
+    "The accepted syntax: \nval\nval1--val2\n< val\n> val\n< val1 > val2\n");
+
+  m_ui.precursorChargeLineEdit->setToolTip(
+    "The accepted syntax: \nval\nval1--val2\n< val\n> val\n< val1 > val2\n");
+
   // Make the connections
 
   connect(mp_precisionWidget,
@@ -740,7 +759,7 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 void
 MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 {
-  //qDebug() << "Integration type:" << integration_type;
+  // qDebug() << "Integration type:" << integration_type;
 
   // We need to craft a brand new processing flow because we do not want to
   // pollute the member datum.
@@ -761,8 +780,8 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   step_p->setMzIntegrationParams(
     local_processing_flow.getDefaultMzIntegrationParams());
 
-  //qDebug() << "At integration time, mz integration params"
-           //<< local_processing_flow.getDefaultMzIntegrationParams().toString();
+  // qDebug() << "At integration time, mz integration params"
+  //<< local_processing_flow.getDefaultMzIntegrationParams().toString();
 
   // At this point, make sure we document in the processing flow the other
   // critical parameters: the RT and DT values along with the MS fragmentation
@@ -783,8 +802,8 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   if(!vector_of_qualified_mass_spectra.size())
     return;
 
-  //qDebug() << "The number of spectra recorded for integration:"
-           //<< vector_of_qualified_mass_spectra.size();
+  // qDebug() << "The number of spectra recorded for integration:"
+  //<< vector_of_qualified_mass_spectra.size();
 
   // We have finished documenting the flow's step, append it to the processing
   // flow.
