@@ -241,7 +241,7 @@ OpenMsRunDataSetsDlg::changePlottingColor()
 
   // We need to let the user select a color.
 
-  ColorSelector color_selector;
+  libmassgui::ColorSelector color_selector;
 
   QColor new_color = color_selector.chooseColor();
 
@@ -476,7 +476,7 @@ OpenMsRunDataSetsDlg::removeMsRunDataSet(
 
   QColor color;
   color = brush.color();
-  ColorSelector::releaseColor(color);
+  libmassgui::ColorSelector::releaseColor(color);
 
   m_msRunDataSetListWidgetItemMap.erase(ms_run_data_set_csp);
 
