@@ -75,8 +75,13 @@
 
 #include "ConsoleWnd.hpp"
 
-#include "MassPeakShaperDlg.hpp"
-#include "IsoSpecDlg.hpp"
+#include <libmassgui/includes/libmassgui/IsotopicClusterGeneratorDlg.hpp>
+#include <libmassgui/includes/libmassgui/IsotopicClusterShaperDlg.hpp>
+
+#include <libmass/MassDataServer.hpp> 
+#include <libmass/MassDataClient.hpp> 
+#include <libmassgui/includes/libmassgui/MassDataClientServerConfigDlg.hpp>
+
 
 #include "../nongui/AnalysisPreferences.hpp"
 #include "AnalysisPreferencesDlg.hpp"
@@ -297,7 +302,7 @@ class ProgramWindow : public QMainWindow
   /////////////////////////////  protected  /////////////////////////////
   protected:
   //! The name of the module, at the moment massXpert or mineXpert.
-  QString m_moduleName = "mineXpert2";
+  QString m_applicationName = "mineXpert2";
 
   std::size_t m_loadedFileCount = 0;
   QString m_msRunIdPrefix       = "file-";
@@ -335,11 +340,10 @@ class ProgramWindow : public QMainWindow
 
   ConsoleWnd *mp_consoleWnd = nullptr;
 
-  MassPeakShaperDlg *mp_massPeakShaperDlg = nullptr;
+  libmassgui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg               = nullptr;
+  libmassgui::IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
 
-  IsoSpecDlg *mp_isoSpecDlg = nullptr;
-
-  AnalysisPreferences *mpa_analysisPreferences = nullptr;
+  libmassgui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg = nullptr;
 
   AnalysisPreferencesDlg *mp_analysisPreferencesDlg = nullptr;
 
@@ -347,6 +351,12 @@ class ProgramWindow : public QMainWindow
 
   AboutDlg *mp_aboutDlg = nullptr;
 
+
+  AnalysisPreferences *mpa_analysisPreferences = nullptr;
+
+  libmass::MassDataClient *mpa_massDataClient = nullptr;
+  libmass::MassDataServer *mpa_massDataServer = nullptr;
+
   // The map that relates each MS run data set with the corresponding ms run
   // data set table view window.
   std::map<MsRunDataSetCstSPtr, MsRunDataSetTableViewWnd *>
@@ -359,6 +369,9 @@ class ProgramWindow : public QMainWindow
   QMenu *mp_helpMenu                = nullptr;
   QAction *mp_openFullMsFileAct     = nullptr;
   QAction *mp_openStreamedMsFileAct = nullptr;
+  QAction *mp_isotopicClusterGeneratorDlgAct;
+  QAction *mp_isotopicClusterShaperDlgAct;
+  QAction *mp_clientServerConfigDlgAct;
   QAction *mp_quitAct;
 
   void writeSettings();
@@ -399,8 +412,8 @@ class ProgramWindow : public QMainWindow
   void showMsRunDataSetTableViewWnd(MsRunDataSetCstSPtr ms_run_data_set_csp,
                                     const QColor &color);
 
-  void showMassPeakShaperDlg();
-  Q_INVOKABLE void showIsoSpecDlg();
+  void showIsotopicClusterShaperDlg();
+  Q_INVOKABLE void showIsotopicClusterGeneratorDlg();
 
   void cancelOperationPushButtonClicked();
 
@@ -408,6 +421,17 @@ class ProgramWindow : public QMainWindow
 
   void calculateInitialMsRunDataSetStatistics(
     MsRunDataSetCstSPtr ms_run_data_set_csp);
+
+  bool startServer();
+  void stopServer();
+  bool startClient(const QString &ip_address, int port_number, int connection_frequency = 1);
+  void stopClient();
+
+  void dispatchReceivedData(const QByteArray &byte_array);
+
+  private slots:
+
+  void massDataToBeServed(const QByteArray &byte_array);
 };
 
 
