@@ -79,10 +79,11 @@ class TicXicChromTracePlotWnd : public BaseTracePlotWnd
   void
   calculateInitialTicChromatogram(MsRunDataSetCstSPtr &ms_run_data_set_csp);
 
-  void integrateToRt(QCPAbstractPlottable *plottable_p,
+  void integrateToRt(
+    QCPAbstractPlottable *plottable_p,
     std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
       qualified_mass_spectra_sp,
-                     const ProcessingFlow &processing_flow);
+    const ProcessingFlow &processing_flow);
 
   void integrateToMz(QCPAbstractPlottable *plottable_p,
                      const ProcessingFlow &processing_flow);
@@ -101,6 +102,10 @@ class TicXicChromTracePlotWnd : public BaseTracePlotWnd
   finishedIntegratingToInitialTicChromatogram(
     MsRunDataSetTreeMassDataIntegratorToRt *mass_data_integrator_p);
 
+  //std::pair<MsRunDataSetCstSPtr, QColor>
+  //initialShimTicChromatogramForSingleMassSpectrumDataSet(
+    //MsRunDataSetCstSPtr ms_run_data_set_csp);
+
   void finishedIntegratingToRt(
     QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
     QCPAbstractPlottable *parent_plottable_p);
