@@ -82,7 +82,10 @@ MsRunDataSet::MsRunDataSet()
 MsRunDataSet::MsRunDataSet(QObject *parent,
                            const pappso::MsRunReaderSPtr ms_run_reader_sp,
                            bool isStreamed)
-  : QObject(parent), msp_msRunReader(ms_run_reader_sp), m_isStreamed(isStreamed)
+  : QObject(parent),
+    msp_msRunReader(ms_run_reader_sp),
+    mcsp_msRunId(ms_run_reader_sp->getMsRunId()),
+    m_isStreamed(isStreamed)
 {
   // qDebug() << "ms run id:" << ms_run_reader_sp->getMsRunId()->toString();
 
@@ -91,9 +94,25 @@ MsRunDataSet::MsRunDataSet(QObject *parent,
 }
 
 
+MsRunDataSet::MsRunDataSet(QObject *parent,
+                           const pappso::MsRunIdCstSPtr ms_run_id_csp,
+                           bool isStreamed)
+  : QObject(parent),
+    msp_msRunReader(nullptr),
+    mcsp_msRunId(ms_run_id_csp),
+    m_isStreamed(isStreamed)
+{
+  // qDebug() << "ms run id:" << ms_run_reader_sp->getMsRunId()->toString();
+
+  msp_msRunDataSetTree =
+    std::make_shared<pappso::MsRunDataSetTree>(ms_run_id_csp);
+}
+
+
 MsRunDataSet::MsRunDataSet(const MsRunDataSet &other)
   : QObject(other.parent()),
     msp_msRunReader(other.msp_msRunReader),
+    mcsp_msRunId(other.mcsp_msRunId),
     m_isStreamed(other.m_isStreamed)
 {
 }
@@ -159,6 +178,20 @@ MsRunDataSet::isStreamed() const
 }
 
 
+void
+MsRunDataSet::setMsRunId(pappso::MsRunIdCstSPtr ms_run_id_csp)
+{
+  mcsp_msRunId = ms_run_id_csp;
+}
+
+
+pappso::MsRunIdCstSPtr
+MsRunDataSet::getMsRunId() const
+{
+  return mcsp_msRunId;
+}
+
+
 pappso::MsRunReaderSPtr
 MsRunDataSet::getMsRunReaderSPtr()
 {
@@ -173,13 +206,6 @@ MsRunDataSet::getMsRunReaderCstSPtr() const
 }
 
 
-pappso::MsRunIdCstSPtr
-MsRunDataSet::getMsRunId() const
-{
-  return msp_msRunReader->getMsRunId();
-}
-
-
 void
 MsRunDataSet::resetStatistics()
 {
@@ -227,19 +253,15 @@ MsRunDataSet::craftInitialMzIntegrationParams() const
     // Absolute max m/z value of the whole data set
     m_msRunDataSetStats.m_maxMz,
     // Binning type
-    pappso::BinningType::ARBITRARY,
+    pappso::BinningType::NONE,
     // Decimal places (we do not want to limit the number of digits after the
     // decimal point.
     -1,
     // The size of the m/z bins in Dalton units.
     pappso::PrecisionFactory::getDaltonInstance(
       m_msRunDataSetStats.m_smallestStepMedian),
-
-    // Should apply the m/z shift
-    false,
-    // The m/z shift to apply
-    0.0,
-    // Remove or not zero val data points
+    1, // bin size divisor
+       // Remove or not zero val data points
     true);
 }
 
