@@ -61,6 +61,14 @@ std::vector<ProcessingTypeStringPair> ProcessingType::processingTypes =
   // types.
 	std::pair<QString, QString>("FILE_RT", "File, Tic chrom."),
 
+  // When a mass spectrum is loaded from file or memory or TCP socket.
+	std::pair<QString, QString>("FILE_MZ", "File, Mass spectrum"),
+	std::pair<QString, QString>("CLIPBOARD_MZ", "Clipboard, Mass spectrum"),
+	std::pair<QString, QString>("SOCKET_MZ", "Socket, Mass spectrum"),
+
+  // When a drift spectrum is loaded from file or memory or TCP socket.
+	std::pair<QString, QString>("FILE_DT", "File, Drift spectrum"),
+
 	std::pair<QString, QString>("DATA_TABLE_VIEW_DT", "Data table view, drift spectrum"),
 	std::pair<QString, QString>("DATA_TABLE_VIEW_RT", "Data table view, drift spectrum"),
 
@@ -123,6 +131,7 @@ ProcessingType::registerProcessingTypes()
   /* ANY_DT */
   // clang-format off
   brief_desc_list = {
+    "FILE_DT",
     "DATA_TABLE_VIEW_DT",
     "DT",
     "DT_MZ",
@@ -137,6 +146,9 @@ ProcessingType::registerProcessingTypes()
   /* ANY_MZ */
   // clang-format off
   brief_desc_list = {
+    "FILE_MZ",
+    "CLIPBOARD_MZ",
+    "SOCKET_MZ",
     "MZ",
     "DATA_XIC_MZ",
     "DT_MZ",
